@@ -23,11 +23,12 @@
  */
 
 #include <gtk/gtkrc.h>
+#include "clearlooks_types.h"
 
 typedef struct _ClearlooksRcStyle ClearlooksRcStyle;
 typedef struct _ClearlooksRcStyleClass ClearlooksRcStyleClass;
 
-extern GType clearlooks_type_rc_style G_GNUC_INTERNAL;
+GE_INTERNAL extern GType clearlooks_type_rc_style;
 
 #define CLEARLOOKS_TYPE_RC_STYLE              clearlooks_type_rc_style
 #define CLEARLOOKS_RC_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), CLEARLOOKS_TYPE_RC_STYLE, ClearlooksRcStyle))
@@ -36,20 +37,29 @@ extern GType clearlooks_type_rc_style G_GNUC_INTERNAL;
 #define CLEARLOOKS_IS_RC_STYLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), CLEARLOOKS_TYPE_RC_STYLE))
 #define CLEARLOOKS_RC_STYLE_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), CLEARLOOKS_TYPE_RC_STYLE, ClearlooksRcStyleClass))
 
+/* XXX: needs fixing! */
+typedef enum {
+	CL_FLAG_STYLE             = 1 <<  0,
+	CL_FLAG_SCROLLBAR_COLOR   = 1 <<  1,
+	CL_FLAG_CONTRAST          = 1 <<  2,
+	CL_FLAG_MENUBARSTYLE      = 1 <<  3,
+	CL_FLAG_ANIMATION         = 1 <<  4,
+	CL_FLAG_RADIUS            = 1 <<  5,
+} ClearlooksRcFlags;
+
 struct _ClearlooksRcStyle
 {
-  GtkRcStyle parent_instance;
+	GtkRcStyle parent_instance;
 
-  GdkColor scrollbar_color;
-  gboolean has_scrollbar_color;
-  double contrast;
-  guint8 sunkenmenubar;
-  guint8 progressbarstyle;
-  guint8 menubarstyle;
-  guint8 menuitemstyle;
-  guint8 listviewitemstyle;
-  guint8 scrollbarstyle;
-  gboolean animation;
+	ClearlooksRcFlags flags;
+
+	ClearlooksStyles style;
+  
+	GdkColor scrollbar_color;
+	double contrast;
+	guint8 menubarstyle;
+	gboolean animation;
+	double radius;
 };
 
 struct _ClearlooksRcStyleClass
@@ -57,4 +67,4 @@ struct _ClearlooksRcStyleClass
   GtkRcStyleClass parent_class;
 };
 
-void clearlooks_rc_style_register_type (GTypeModule *module) G_GNUC_INTERNAL;
+GE_INTERNAL void clearlooks_rc_style_register_type (GTypeModule *module);
